import type { IoMessageLevel } from '../io-message';
import { type VALID_CODE } from './codes';
import type { ActionLessMessage, ActionLessRequest, IoMessageCodeCategory, Optional, SimplifiedMessage } from './types';
/**
 * Internal helper that processes log inputs into a consistent format.
 * Handles string interpolation, format strings, and object parameter styles.
 * Applies optional styling and prepares the final message for logging.
 */
export declare function formatMessage<T>(msg: Optional<SimplifiedMessage<T>, 'code'>, category?: IoMessageCodeCategory): ActionLessMessage<T>;
/**
 * Build a message code from level and category. The code must be valid for this function to pass.
 * Otherwise it returns a ToolkitError.
 */
export declare function defaultMessageCode(level: IoMessageLevel, category?: IoMessageCodeCategory): VALID_CODE;
/**
 * Requests a yes/no confirmation from the IoHost.
 */
export declare const confirm: (code: VALID_CODE, question: string, motivation: string, defaultResponse: boolean, concurrency?: number) => ActionLessRequest<{
    motivation: string;
    concurrency?: number;
}, boolean>;
/**
 * Prompt for a a response from the IoHost.
 */
export declare const prompt: <T, U>(code: VALID_CODE, message: string, defaultResponse: U, payload?: T) => ActionLessRequest<T, U>;
/**
 * Creates an error level message.
 * Errors must always have a unique code.
 */
export declare const error: <T>(message: string, code: VALID_CODE, payload?: T) => ActionLessMessage<T>;
/**
 * Creates a result level message and represents the most important message for a given action.
 *
 * They should be used sparsely, with an action usually having no or exactly one result.
 * However actions that operate on Cloud Assemblies might include a result per Stack.
 * Unlike other messages, results must always have a code and a payload.
 */
export declare const result: <T>(message: string, code: VALID_CODE, payload: T) => ActionLessMessage<T>;
/**
 * Creates a warning level message.
 */
export declare const warn: <T>(message: string, code?: VALID_CODE, payload?: T) => ActionLessMessage<T>;
/**
 * Creates an info level message.
 */
export declare const info: <T>(message: string, code?: VALID_CODE, payload?: T) => ActionLessMessage<T>;
/**
 * Creates a debug level message.
 */
export declare const debug: <T>(message: string, code?: VALID_CODE, payload?: T) => ActionLessMessage<T>;
/**
 * Creates a trace level message.
 */
export declare const trace: <T>(message: string, code?: VALID_CODE, payload?: T) => ActionLessMessage<T>;
/**
 * Creates an info level success message in green text.
 * @deprecated
 */
export declare const success: <T>(message: string, code?: VALID_CODE, payload?: T) => ActionLessMessage<T>;
/**
 * Creates an info level message in bold text.
 * @deprecated
 */
export declare const highlight: <T>(message: string, code?: VALID_CODE, payload?: T) => ActionLessMessage<T>;
